@@ -1,6 +1,5 @@
 from abc import ABCMeta, abstractmethod
 from typing import Generic, TypeVar
-from ._util import aiter_compat
 import trio
 
 
@@ -10,6 +9,7 @@ class Clock(metaclass=ABCMeta):
     """The interface for custom run loop clocks.
 
     """
+
     __slots__ = ()
 
     @abstractmethod
@@ -64,6 +64,7 @@ class Instrument(metaclass=ABCMeta):
     of these methods are optional. This class serves mostly as documentation.
 
     """
+
     __slots__ = ()
 
     def before_run(self):
@@ -80,7 +81,7 @@ class Instrument(metaclass=ABCMeta):
         """Called when the given task is created.
 
         Args:
-            task (trio.hazmat.Task): The new task.
+            task (trio.lowlevel.Task): The new task.
 
         """
 
@@ -91,7 +92,7 @@ class Instrument(metaclass=ABCMeta):
         runnable tasks ahead of it.
 
         Args:
-            task (trio.hazmat.Task): The task that became runnable.
+            task (trio.lowlevel.Task): The task that became runnable.
 
         """
 
@@ -99,7 +100,7 @@ class Instrument(metaclass=ABCMeta):
         """Called immediately before we resume running the given task.
 
         Args:
-            task (trio.hazmat.Task): The task that is about to run.
+            task (trio.lowlevel.Task): The task that is about to run.
 
         """
 
@@ -107,7 +108,7 @@ class Instrument(metaclass=ABCMeta):
         """Called when we return to the main run loop after a task has yielded.
 
         Args:
-            task (trio.hazmat.Task): The task that just ran.
+            task (trio.lowlevel.Task): The task that just ran.
 
         """
 
@@ -115,7 +116,7 @@ class Instrument(metaclass=ABCMeta):
         """Called when the given task exits.
 
         Args:
-            task (trio.hazmat.Task): The finished task.
+            task (trio.lowlevel.Task): The finished task.
 
         """
 
@@ -145,12 +146,11 @@ class HostnameResolver(metaclass=ABCMeta):
     See :func:`trio.socket.set_custom_hostname_resolver`.
 
     """
+
     __slots__ = ()
 
     @abstractmethod
-    async def getaddrinfo(
-        self, host, port, family=0, type=0, proto=0, flags=0
-    ):
+    async def getaddrinfo(self, host, port, family=0, type=0, proto=0, flags=0):
         """A custom implementation of :func:`~trio.socket.getaddrinfo`.
 
         Called by :func:`trio.socket.getaddrinfo`.
@@ -182,6 +182,7 @@ class SocketFactory(metaclass=ABCMeta):
     See :func:`trio.socket.set_custom_socket_factory`.
 
     """
+
     @abstractmethod
     def socket(self, family=None, type=None, proto=None):
         """Create and return a socket object.
@@ -225,6 +226,7 @@ class AsyncResource(metaclass=ABCMeta):
     ``__aenter__`` and ``__aexit__`` should be adequate for all subclasses.
 
     """
+
     __slots__ = ()
 
     @abstractmethod
@@ -278,6 +280,7 @@ class SendStream(AsyncResource):
     :class:`SendChannel`.
 
     """
+
     __slots__ = ()
 
     @abstractmethod
@@ -383,6 +386,7 @@ class ReceiveStream(AsyncResource):
     byte, and the loop automatically exits when reaching end-of-file.
 
     """
+
     __slots__ = ()
 
     @abstractmethod
@@ -414,7 +418,6 @@ class ReceiveStream(AsyncResource):
 
         """
 
-    @aiter_compat
     def __aiter__(self):
         return self
 
@@ -435,6 +438,7 @@ class Stream(SendStream, ReceiveStream):
     step further and implement :class:`HalfCloseableStream`.
 
     """
+
     __slots__ = ()
 
 
@@ -443,6 +447,7 @@ class HalfCloseableStream(Stream):
     part of the stream without closing the receive part.
 
     """
+
     __slots__ = ()
 
     @abstractmethod
@@ -521,6 +526,7 @@ class Listener(AsyncResource, Generic[T_resource]):
     or using an ``async with`` block.
 
     """
+
     __slots__ = ()
 
     @abstractmethod
@@ -562,6 +568,7 @@ class SendChannel(AsyncResource, Generic[SendType]):
     `SendStream`.
 
     """
+
     __slots__ = ()
 
     @abstractmethod
@@ -606,6 +613,7 @@ class ReceiveChannel(AsyncResource, Generic[ReceiveType]):
     `ReceiveStream`.
 
     """
+
     __slots__ = ()
 
     @abstractmethod
@@ -629,7 +637,6 @@ class ReceiveChannel(AsyncResource, Generic[ReceiveType]):
 
         """
 
-    @aiter_compat
     def __aiter__(self):
         return self
 
