@@ -7,6 +7,7 @@ import errno
 
 from .. import _core
 from ._run import _public
+from ._wakeup_socketpair import WakeupSocketpair
 
 
 @attr.s(slots=True, eq=False, frozen=True)
@@ -21,6 +22,15 @@ class KqueueIOManager:
     _kqueue = attr.ib(factory=select.kqueue)
     # {(ident, filter): Task or UnboundedQueue}
     _registered = attr.ib(factory=dict)
+    _force_wakeup = attr.ib(factory=WakeupSocketpair)
+    _force_wakeup_fd = attr.ib(default=None)
+
+    def __attrs_post_init__(self):
+        force_wakeup_event = select.kevent(
+            self._force_wakeup.wakeup_sock, select.KQ_FILTER_READ, select.KQ_EV_ADD
+        )
+        self._kqueue.control([force_wakeup_event], 0)
+        self._force_wakeup_fd = self._force_wakeup.wakeup_sock.fileno()
 
     def statistics(self):
         tasks_waiting = 0
@@ -30,15 +40,15 @@ class KqueueIOManager:
                 tasks_waiting += 1
             else:
                 monitors += 1
-        return _KqueueStatistics(
-            tasks_waiting=tasks_waiting,
-            monitors=monitors,
-        )
+        return _KqueueStatistics(tasks_waiting=tasks_waiting, monitors=monitors,)
 
     def close(self):
         self._kqueue.close()
 
-    def handle_io(self, timeout):
+    def force_wakeup(self):
+        self._force_wakeup.wakeup_thread_and_signal_safe()
+
+    def get_events(self, timeout):
         # max_events must be > 0 or kqueue gets cranky
         # and we generally want this to be strictly larger than the actual
         # number of events we get, so that we can tell that we've gotten
@@ -53,8 +63,14 @@ class KqueueIOManager:
             else:
                 timeout = 0
                 # and loop back to the start
+        return events
+
+    def process_events(self, events):
         for event in events:
             key = (event.ident, event.filter)
+            if event.ident == self._force_wakeup_fd:
+                self._force_wakeup.drain()
+                continue
             receiver = self._registered[key]
             if event.flags & select.KQ_EV_ONESHOT:
                 del self._registered[key]
@@ -84,8 +100,7 @@ class KqueueIOManager:
         key = (ident, filter)
         if key in self._registered:
             raise _core.BusyResourceError(
-                "attempt to register multiple listeners for same "
-                "ident/filter pair"
+                "attempt to register multiple listeners for same ident/filter pair"
             )
         q = _core.UnboundedQueue()
         self._registered[key] = q
@@ -99,8 +114,7 @@ class KqueueIOManager:
         key = (ident, filter)
         if key in self._registered:
             raise _core.BusyResourceError(
-                "attempt to register multiple listeners for same "
-                "ident/filter pair"
+                "attempt to register multiple listeners for same ident/filter pair"
             )
         self._registered[key] = _core.current_task()
 
@@ -134,9 +148,7 @@ class KqueueIOManager:
                 # the fact... oh well, you can't have everything.)
                 #
                 # FreeBSD reports this using EBADF. macOS uses ENOENT.
-                if exc.errno in (
-                    errno.EBADF, errno.ENOENT
-                ):  # pragma: no branch
+                if exc.errno in (errno.EBADF, errno.ENOENT,):  # pragma: no branch
                     pass
                 else:  # pragma: no cover
                     # As far as we know, this branch can't happen.
