@@ -16,8 +16,10 @@ import sniffio
 import pytest
 
 from .tutil import (
-    slow, check_sequence_matches, gc_collect_harder,
-    ignore_coroutine_never_awaited_warnings
+    slow,
+    check_sequence_matches,
+    gc_collect_harder,
+    ignore_coroutine_never_awaited_warnings,
 )
 
 from ... import _core
@@ -128,8 +130,7 @@ async def test_basic_interleave():
         nursery.start_soon(looper, "b", record)
 
     check_sequence_matches(
-        record,
-        [{("a", 0), ("b", 0)}, {("a", 1), ("b", 1)}, {("a", 2), ("b", 2)}]
+        record, [{("a", 0), ("b", 0)}, {("a", 1), ("b", 1)}, {("a", 2), ("b", 2)}],
     )
 
 
@@ -173,8 +174,10 @@ def test_main_and_task_both_crash():
     with pytest.raises(_core.MultiError) as excinfo:
         _core.run(main)
     print(excinfo.value)
-    assert {type(exc)
-            for exc in excinfo.value.exceptions} == {ValueError, KeyError}
+    assert {type(exc) for exc in excinfo.value.exceptions} == {
+        ValueError,
+        KeyError,
+    }
 
 
 def test_two_child_crashes():
@@ -188,8 +191,10 @@ def test_two_child_crashes():
 
     with pytest.raises(_core.MultiError) as excinfo:
         _core.run(main)
-    assert {type(exc)
-            for exc in excinfo.value.exceptions} == {ValueError, KeyError}
+    assert {type(exc) for exc in excinfo.value.exceptions} == {
+        ValueError,
+        KeyError,
+    }
 
 
 async def test_child_crash_wakes_parent():
@@ -267,7 +272,7 @@ async def test_current_task():
 
 async def test_root_task():
     root = _core.current_root_task()
-    assert root.parent_nursery is None
+    assert root.parent_nursery is root.eventual_parent_nursery is None
 
 
 def test_out_of_context():
@@ -394,9 +399,9 @@ def test_instruments(recwarn):
     # reschedules the task immediately upon yielding, before the
     # after_task_step event fires.
     expected = (
-        [("before_run",), ("schedule", task)] +
-        [("before", task), ("schedule", task), ("after", task)] * 5 +
-        [("before", task), ("after", task), ("after_run",)]
+        [("before_run",), ("schedule", task)]
+        + [("before", task), ("schedule", task), ("after", task)] * 5
+        + [("before", task), ("after", task), ("after_run",)]
     )
     assert len(r1.record) > len(r2.record) > len(r3.record)
     assert r1.record == r2.record + r3.record
@@ -432,16 +437,16 @@ def test_instruments_interleave():
             ("after", tasks["t1"]),
             ("before", tasks["t2"]),
             ("schedule", tasks["t2"]),
-            ("after", tasks["t2"])
+            ("after", tasks["t2"]),
         },
         {
             ("before", tasks["t1"]),
             ("after", tasks["t1"]),
             ("before", tasks["t2"]),
-            ("after", tasks["t2"])
+            ("after", tasks["t2"]),
         },
         ("after_run",),
-    ]  # yapf: disable
+    ]
     print(list(r.filter_tasks(tasks.values())))
     check_sequence_matches(list(r.filter_tasks(tasks.values())), expected)
 
@@ -962,9 +967,7 @@ async def test_cancel_scope_misnesting():
         for exc in exc_info.value.__context__.exceptions:
             assert isinstance(exc, RuntimeError)
             assert "closed before the task exited" in str(exc)
-            cancelled_in_context |= isinstance(
-                exc.__context__, _core.Cancelled
-            )
+            cancelled_in_context |= isinstance(exc.__context__, _core.Cancelled)
         assert cancelled_in_context  # for the sleep_forever
 
     # Trying to exit a cancel scope from an unrelated task raises an error
@@ -1230,9 +1233,14 @@ async def test_exc_info():
         nursery.start_soon(child2)
 
     assert record == [
-        "child1 raise", "child1 sleep", "child2 wake", "child2 sleep again",
-        "child1 re-raise", "child1 success", "child2 re-raise",
-        "child2 success"
+        "child1 raise",
+        "child1 sleep",
+        "child2 wake",
+        "child2 sleep again",
+        "child1 re-raise",
+        "child1 success",
+        "child2 re-raise",
+        "child2 success",
     ]
 
 
@@ -1580,7 +1588,7 @@ async def test_task_tree_introspection():
     tasks = {}
     nurseries = {}
 
-    async def parent():
+    async def parent(task_status=_core.TASK_STATUS_IGNORED):
         tasks["parent"] = _core.current_task()
 
         assert tasks["parent"].child_nurseries == []
@@ -1593,7 +1601,7 @@ async def test_task_tree_introspection():
 
         async with _core.open_nursery() as nursery:
             nurseries["parent"] = nursery
-            nursery.start_soon(child1)
+            await nursery.start(child1)
 
         # Upward links survive after tasks/nurseries exit
         assert nurseries["parent"].parent_task is tasks["parent"]
@@ -1616,8 +1624,19 @@ async def test_task_tree_introspection():
         assert nurseries["child1"].child_tasks == frozenset({tasks["child2"]})
         assert tasks["child2"].child_nurseries == []
 
-    async def child1():
-        tasks["child1"] = _core.current_task()
+    async def child1(task_status=_core.TASK_STATUS_IGNORED):
+        me = tasks["child1"] = _core.current_task()
+        assert me.parent_nursery.parent_task is tasks["parent"]
+        assert me.parent_nursery is not nurseries["parent"]
+        assert me.eventual_parent_nursery is nurseries["parent"]
+        task_status.started()
+        assert me.parent_nursery is nurseries["parent"]
+        assert me.eventual_parent_nursery is None
+
+        # Wait for the start() call to return and close its internal nursery, to
+        # ensure consistent results in child2:
+        await _core.wait_all_tasks_blocked()
+
         async with _core.open_nursery() as nursery:
             nurseries["child1"] = nursery
             nursery.start_soon(child2)
@@ -1625,6 +1644,11 @@ async def test_task_tree_introspection():
     async with _core.open_nursery() as nursery:
         nursery.start_soon(parent)
 
+    # There are no pending starts, so no one should have a non-None
+    # eventual_parent_nursery
+    for task in tasks.values():
+        assert task.eventual_parent_nursery is None
+
 
 async def test_nursery_closure():
     async def child1(nursery):
@@ -1705,8 +1729,7 @@ def test_nice_error_on_bad_calls_to_run_or_spawn():
             yield arg
 
         with pytest.raises(
-            TypeError,
-            match="expected an async function but got an async generator"
+            TypeError, match="expected an async function but got an async generator",
         ):
             bad_call(async_gen, 0)
 
@@ -1714,6 +1737,7 @@ def test_nice_error_on_bad_calls_to_run_or_spawn():
 def test_calling_asyncio_function_gives_nice_error():
     async def child_xyzzy():
         import asyncio
+
         await asyncio.Future()
 
     async def misguided():
@@ -1734,6 +1758,7 @@ async def test_asyncio_function_inside_nursery_does_not_explode():
     with pytest.raises(TypeError) as excinfo:
         async with _core.open_nursery() as nursery:
             import asyncio
+
             nursery.start_soon(sleep_forever)
             await asyncio.Future()
     assert "asyncio" in str(excinfo.value)
@@ -1757,10 +1782,10 @@ async def test_trivial_yields():
             async with _core.open_nursery():
                 raise KeyError
         assert len(excinfo.value.exceptions) == 2
-        assert {type(e)
-                for e in excinfo.value.exceptions} == {
-                    KeyError, _core.Cancelled
-                }
+        assert {type(e) for e in excinfo.value.exceptions} == {
+            KeyError,
+            _core.Cancelled,
+        }
 
 
 async def test_nursery_start(autojump_clock):
@@ -1772,9 +1797,7 @@ async def test_nursery_start(autojump_clock):
         with pytest.raises(TypeError):
             await nursery.start(no_args)
 
-    async def sleep_then_start(
-        seconds, *, task_status=_core.TASK_STATUS_IGNORED
-    ):
+    async def sleep_then_start(seconds, *, task_status=_core.TASK_STATUS_IGNORED):
         repr(task_status)  # smoke test
         await sleep(seconds)
         task_status.started(seconds)
@@ -1838,9 +1861,7 @@ async def test_nursery_start(autojump_clock):
 
     # and if after the no-op started(), the child crashes, the error comes out
     # of start()
-    async def raise_keyerror_after_started(
-        task_status=_core.TASK_STATUS_IGNORED
-    ):
+    async def raise_keyerror_after_started(task_status=_core.TASK_STATUS_IGNORED,):
         task_status.started()
         raise KeyError("whoopsiedaisy")
 
@@ -1849,8 +1870,10 @@ async def test_nursery_start(autojump_clock):
             cs.cancel()
             with pytest.raises(_core.MultiError) as excinfo:
                 await nursery.start(raise_keyerror_after_started)
-    assert {type(e)
-            for e in excinfo.value.exceptions} == {_core.Cancelled, KeyError}
+    assert {type(e) for e in excinfo.value.exceptions} == {
+        _core.Cancelled,
+        KeyError,
+    }
 
     # trying to start in a closed nursery raises an error immediately
     async with _core.open_nursery() as closed_nursery:
@@ -1990,9 +2013,7 @@ async def test_nursery_stop_async_iteration():
 
         async def __anext__(self):
             nexts = self.nexts
-            items = [
-                None,
-            ] * len(nexts)
+            items = [None,] * len(nexts)
             got_stop = False
 
             def handle(exc):
@@ -2082,7 +2103,7 @@ async def test_contextvar_multitask():
 
 
 def test_system_task_contexts():
-    cvar = contextvars.ContextVar('qwilfish')
+    cvar = contextvars.ContextVar("qwilfish")
     cvar.set("water")
 
     async def system_task():
@@ -2132,7 +2153,7 @@ def test_Cancelled_init():
 
 def test_Cancelled_str():
     cancelled = _core.Cancelled._create()
-    assert str(cancelled) == 'Cancelled'
+    assert str(cancelled) == "Cancelled"
 
 
 def test_Cancelled_subclass():
@@ -2190,9 +2211,7 @@ async def test_permanently_detach_coroutine_object():
         await async_yield(yield_value)
 
     async with _core.open_nursery() as nursery:
-        nursery.start_soon(
-            detachable_coroutine, outcome.Value(None), "I'm free!"
-        )
+        nursery.start_soon(detachable_coroutine, outcome.Value(None), "I'm free!")
 
     # If we get here then Trio thinks the task has exited... but the coroutine
     # is still iterable
@@ -2207,9 +2226,7 @@ async def test_permanently_detach_coroutine_object():
     pdco_outcome = None
     with pytest.raises(KeyError):
         async with _core.open_nursery() as nursery:
-            nursery.start_soon(
-                detachable_coroutine, outcome.Error(KeyError()), "uh oh"
-            )
+            nursery.start_soon(detachable_coroutine, outcome.Error(KeyError()), "uh oh")
     throw_in = ValueError()
     assert task.coro.throw(throw_in) == "uh oh"
     assert pdco_outcome == outcome.Error(throw_in)
@@ -2219,9 +2236,7 @@ async def test_permanently_detach_coroutine_object():
     async def bad_detach():
         async with _core.open_nursery():
             with pytest.raises(RuntimeError) as excinfo:
-                await _core.permanently_detach_coroutine_object(
-                    outcome.Value(None)
-                )
+                await _core.permanently_detach_coroutine_object(outcome.Value(None))
             assert "open nurser" in str(excinfo.value)
 
     async with _core.open_nursery() as nursery:
@@ -2252,9 +2267,7 @@ async def test_detach_and_reattach_coroutine_object():
         await async_yield(2)
 
         with pytest.raises(RuntimeError) as excinfo:
-            await _core.reattach_detached_coroutine_object(
-                unrelated_task, None
-            )
+            await _core.reattach_detached_coroutine_object(unrelated_task, None)
         assert "does not match" in str(excinfo.value)
 
         await _core.reattach_detached_coroutine_object(task, "byebye")
