@@ -7,7 +7,6 @@ from functools import wraps as _wraps
 import idna as _idna
 
 import trio
-from ._util import fspath
 from . import _core
 
 
@@ -30,7 +29,7 @@ class _try_sync:
             return self._blocking_exc_override(exc)
 
     async def __aenter__(self):
-        await trio.hazmat.checkpoint_if_cancelled()
+        await trio.lowlevel.checkpoint_if_cancelled()
 
     async def __aexit__(self, etype, value, tb):
         if value is not None and self._is_blocking_io_error(value):
@@ -38,7 +37,7 @@ class _try_sync:
             # block
             return True
         else:
-            await trio.hazmat.cancel_shielded_checkpoint()
+            await trio.lowlevel.cancel_shielded_checkpoint()
             # Let the return or exception propagate
             return False
 
@@ -151,8 +150,10 @@ async def getaddrinfo(host, port, family=0, type=0, proto=0, flags=0):
     # with the _NUMERIC_ONLY flags set, and then only spawn a thread if that
     # fails with EAI_NONAME:
     def numeric_only_failure(exc):
-        return isinstance(exc, _stdlib_socket.gaierror) and \
-            exc.errno == _stdlib_socket.EAI_NONAME
+        return (
+            isinstance(exc, _stdlib_socket.gaierror)
+            and exc.errno == _stdlib_socket.EAI_NONAME
+        )
 
     async with _try_sync(numeric_only_failure):
         return _stdlib_socket.getaddrinfo(
@@ -186,7 +187,7 @@ async def getaddrinfo(host, port, family=0, type=0, proto=0, flags=0):
             type,
             proto,
             flags,
-            cancellable=True
+            cancellable=True,
         )
 
 
@@ -267,7 +268,7 @@ def socket(
     family=_stdlib_socket.AF_INET,
     type=_stdlib_socket.SOCK_STREAM,
     proto=0,
-    fileno=None
+    fileno=None,
 ):
     """Create a new Trio socket, like :func:`socket.socket`.
 
@@ -280,9 +281,7 @@ def socket(
         if sf is not None:
             return sf.socket(family, type, proto)
     else:
-        family, type, proto = _sniff_sockopts_for_fileno(
-            family, type, proto, fileno
-        )
+        family, type, proto = _sniff_sockopts_for_fileno(family, type, proto, fileno)
     stdlib_socket = _stdlib_socket.socket(family, type, proto, fileno)
     return from_stdlib_socket(stdlib_socket)
 
@@ -296,13 +295,8 @@ def _sniff_sockopts_for_fileno(family, type, proto, fileno):
     # and then we'll throw it away and construct a new one with the correct metadata.
     if not _sys.platform == "linux":
         return family, type, proto
-    try:
-        from socket import SO_DOMAIN, SO_PROTOCOL
-    except ImportError:
-        # Only available on 3.6 and above:
-        SO_PROTOCOL = 38
-        SO_DOMAIN = 39
-    from socket import SOL_SOCKET, SO_TYPE
+    from socket import SO_DOMAIN, SO_PROTOCOL, SOL_SOCKET, SO_TYPE
+
     sockobj = _stdlib_socket.socket(family, type, proto, fileno=fileno)
     try:
         family = sockobj.getsockopt(SOL_SOCKET, SO_DOMAIN)
@@ -331,8 +325,6 @@ _SOCK_TYPE_MASK = ~(
 )
 
 
-# Note that this is *not* in __all__.
-#
 # This function will modify the given socket to match the behavior in python
 # 3.7. This will become unecessary and can be removed when support for versions
 # older than 3.7 is dropped.
@@ -347,15 +339,13 @@ def _make_simple_sock_method_wrapper(methname, wait_fn, maybe_avail=False):
     async def wrapper(self, *args, **kwargs):
         return await self._nonblocking_helper(fn, args, kwargs, wait_fn)
 
-    wrapper.__doc__ = (
-        """Like :meth:`socket.socket.{}`, but async.
+    wrapper.__doc__ = f"""Like :meth:`socket.socket.{methname}`, but async.
 
-            """.format(methname)
-    )
+            """
     if maybe_avail:
         wrapper.__doc__ += (
-            "Only available on platforms where :meth:`socket.socket.{}` "
-            "is available.".format(methname)
+            f"Only available on platforms where :meth:`socket.socket.{methname}` is "
+            "available."
         )
     return wrapper
 
@@ -452,14 +442,16 @@ class _SocketType(SocketType):
         return _SocketType(self._sock.dup())
 
     def close(self):
-        trio.hazmat.notify_closing(self._sock)
-        self._sock.close()
+        if self._sock.fileno() != -1:
+            trio.lowlevel.notify_closing(self._sock)
+            self._sock.close()
 
     async def bind(self, address):
         address = await self._resolve_local_address(address)
         if (
             hasattr(_stdlib_socket, "AF_UNIX")
-            and self.family == _stdlib_socket.AF_UNIX and address[0]
+            and self.family == _stdlib_socket.AF_UNIX
+            and address[0]
         ):
             # Use a thread for the filesystem traversal (unless it's an
             # abstract domain socket)
@@ -505,16 +497,15 @@ class _SocketType(SocketType):
         elif self._sock.family == _stdlib_socket.AF_INET6:
             if not isinstance(address, tuple) or not 2 <= len(address) <= 4:
                 raise ValueError(
-                    "address should be a (host, port, [flowinfo, [scopeid]]) "
-                    "tuple"
+                    "address should be a (host, port, [flowinfo, [scopeid]]) tuple"
                 )
         elif self._sock.family == _stdlib_socket.AF_UNIX:
-            await trio.hazmat.checkpoint()
+            await trio.lowlevel.checkpoint()
             # unwrap path-likes
-            return fspath(address)
+            return _os.fspath(address)
 
         else:
-            await trio.hazmat.checkpoint()
+            await trio.lowlevel.checkpoint()
             return address
         host, port, *_ = address
         # Special cases to match the stdlib, see gh-277
@@ -530,9 +521,7 @@ class _SocketType(SocketType):
         # no ipv6.
         # flags |= AI_ADDRCONFIG
         if self._sock.family == _stdlib_socket.AF_INET6:
-            if not self._sock.getsockopt(
-                IPPROTO_IPV6, _stdlib_socket.IPV6_V6ONLY
-            ):
+            if not self._sock.getsockopt(IPPROTO_IPV6, _stdlib_socket.IPV6_V6ONLY):
                 flags |= _stdlib_socket.AI_V4MAPPED
         gai_res = await getaddrinfo(
             host, port, self._sock.family, self.type, self._sock.proto, flags
@@ -677,9 +666,7 @@ class _SocketType(SocketType):
             self._sock.close()
             raise
         # Okay, the connect finished, but it might have failed:
-        err = self._sock.getsockopt(
-            _stdlib_socket.SOL_SOCKET, _stdlib_socket.SO_ERROR
-        )
+        err = self._sock.getsockopt(_stdlib_socket.SOL_SOCKET, _stdlib_socket.SO_ERROR)
         if err != 0:
             raise OSError(err, "Error in connect: " + _os.strerror(err))
 
@@ -693,17 +680,13 @@ class _SocketType(SocketType):
     # recv_into
     ################################################################
 
-    recv_into = _make_simple_sock_method_wrapper(
-        "recv_into", _core.wait_readable
-    )
+    recv_into = _make_simple_sock_method_wrapper("recv_into", _core.wait_readable)
 
     ################################################################
     # recvfrom
     ################################################################
 
-    recvfrom = _make_simple_sock_method_wrapper(
-        "recvfrom", _core.wait_readable
-    )
+    recvfrom = _make_simple_sock_method_wrapper("recvfrom", _core.wait_readable)
 
     ################################################################
     # recvfrom_into
