@@ -9,126 +9,18 @@ import outcome
 import trio
 
 from ._sync import CapacityLimiter
-from ._core import enable_ki_protection, disable_ki_protection, RunVar, TrioToken
+from ._core import (
+    enable_ki_protection,
+    disable_ki_protection,
+    RunVar,
+    TrioToken,
+    start_thread_soon,
+)
 from ._util import coroutine_or_error
 
 # Global due to Threading API, thread local storage for trio token
 TOKEN_LOCAL = threading.local()
 
-
-class BlockingTrioPortal:
-    def __init__(self, trio_token=None):
-        if trio_token is None:
-            trio_token = trio.lowlevel.current_trio_token()
-        self._trio_token = trio_token
-
-    def run(self, afn, *args):
-        return from_thread_run(afn, *args, trio_token=self._trio_token)
-
-    def run_sync(self, fn, *args):
-        return from_thread_run_sync(fn, *args, trio_token=self._trio_token)
-
-
-################################################################
-
-# XX at some point it probably makes sense to implement some sort of thread
-# pool? Or at least that's what everyone says.
-#
-# There are two arguments for thread pools:
-# - speed (re-using threads instead of starting new ones)
-# - throttling (if you have 1000 tasks, queue them up instead of spawning 1000
-#   threads and running out of memory)
-#
-# Regarding speed, it's not clear how much of an advantage this is. Some
-# numbers on my Linux laptop:
-#
-# Spawning and then joining a thread:
-#
-# In [25]: %timeit t = threading.Thread(target=lambda: None); t.start(); t.join()
-# 10000 loops, best of 3: 44 µs per loop
-#
-# Using a thread pool:
-#
-# In [26]: tpp = concurrent.futures.ThreadPoolExecutor()
-# In [27]: %timeit tpp.submit(lambda: None).result()
-# <warm up run elided>
-# In [28]: %timeit tpp.submit(lambda: None).result()
-# 10000 loops, best of 3: 40.8 µs per loop
-#
-# What's a fast getaddrinfo look like?
-#
-# # with hot DNS cache:
-# In [23]: %timeit socket.getaddrinfo("google.com", "80")
-# 10 loops, best of 3: 50.9 ms per loop
-#
-# In [29]: %timeit socket.getaddrinfo("127.0.0.1", "80")
-# 100000 loops, best of 3: 9.73 µs per loop
-#
-#
-# So... maybe we can beat concurrent.futures with a super-efficient thread
-# pool or something, but there really is not a lot of headroom here.
-#
-# Of course other systems might be different... here's CPython 3.6 in a
-# Virtualbox VM running Windows 10 on that same Linux laptop:
-#
-# In [13]: %timeit t = threading.Thread(target=lambda: None); t.start(); t.join()
-# 10000 loops, best of 3: 127 µs per loop
-#
-# In [18]: %timeit tpp.submit(lambda: None).result()
-# 10000 loops, best of 3: 31.9 µs per loop
-#
-# So on Windows there *might* be an advantage? You've gotta be doing a lot of
-# connections, with very fast DNS indeed, for that 100 us to matter. But maybe
-# someone is.
-#
-#
-# Regarding throttling: this is very much a trade-off. On the one hand, you
-# don't want to overwhelm the machine, obviously. On the other hand, queueing
-# up work on a central thread-pool creates a central coordination point which
-# can potentially create deadlocks and all kinds of fun things. This is very
-# context dependent. For getaddrinfo, whatever, they'll make progress and
-# complete (we hope), and you want to throttle them to some reasonable
-# amount. For calling waitpid() (because just say no to SIGCHLD), then you
-# really want one thread-per-waitpid(), because for all you know the user has
-# written some ridiculous thing like:
-#
-#   for p in processes:
-#       await spawn(p.wait)
-#   # Deadlock here if there are enough processes:
-#   await some_other_subprocess.wait()
-#   for p in processes:
-#       p.terminate()
-#
-# This goes doubly for the sort of wacky thread usage we see in curio.abide
-# (though, I'm not sure if that's actually useful in practice in our context,
-# run_in_trio_thread seems like it might be a nicer synchronization primitive
-# for most uses than trying to make threading.Lock awaitable).
-#
-# See also this very relevant discussion:
-#
-#   https://twistedmatrix.com/trac/ticket/5298
-#
-# "Interacting with the products at Rackspace which use Twisted, I've seen
-# problems caused by thread-pool maximum sizes with some annoying
-# regularity. The basic problem is this: if you have a hard limit on the
-# number of threads, *it is not possible to write a correct program which may
-# require starting a new thread to un-block a blocked pool thread*" - glyph
-#
-# For now, if we want to throttle getaddrinfo I think the simplest thing is
-# for the socket code to have a semaphore for getaddrinfo calls.
-#
-# Regarding the memory overhead of threads, in theory one should be able to
-# reduce this a *lot* for a thread that's just calling getaddrinfo or
-# (especially) waitpid. Windows and pthreads both offer the ability to set
-# thread stack size on a thread-by-thread basis. Unfortunately as of 3.6
-# CPython doesn't expose this in a useful way (all you can do is set it
-# globally for the whole process, so it's - ironically - not thread safe).
-#
-# (It's also unclear how much stack size actually matters; on a 64-bit Linux
-# server with overcommit -- i.e., the most common configuration -- then AFAICT
-# really the only real limit is on stack size actually *used*; how much you
-# *allocate* should be pretty much irrelevant.)
-
 _limiter_local = RunVar("limiter")
 # I pulled this number out of the air; it isn't based on anything. Probably we
 # should make some kind of measurements to pick a good value.
@@ -248,7 +140,7 @@ async def to_thread_run_sync(sync_fn, *args, cancellable=False, limiter=None):
     # for the result – or None if this function was cancelled and we should
     # discard the result.
     task_register = [trio.lowlevel.current_task()]
-    name = "trio-worker-{}".format(next(_thread_counter))
+    name = f"trio.to_thread.run_sync-{next(_thread_counter)}"
     placeholder = ThreadPlaceholder(name)
 
     # This function gets scheduled into the Trio run loop to deliver the
@@ -268,35 +160,37 @@ async def to_thread_run_sync(sync_fn, *args, cancellable=False, limiter=None):
         if task_register[0] is not None:
             trio.lowlevel.reschedule(task_register[0], result)
 
-    # This is the function that runs in the worker thread to do the actual
-    # work and then schedule the call to report_back_in_trio_thread_fn
-    # Since this is spawned in a new thread, the trio token needs to be passed
-    # explicitly to it so it can inject it into thread local storage
-    def worker_thread_fn(trio_token):
-        TOKEN_LOCAL.token = trio_token
+    current_trio_token = trio.lowlevel.current_trio_token()
+
+    def worker_fn():
+        TOKEN_LOCAL.token = current_trio_token
         try:
-            result = outcome.capture(sync_fn, *args)
-            try:
-                trio_token.run_sync_soon(report_back_in_trio_thread_fn, result)
-            except trio.RunFinishedError:
-                # The entire run finished, so our particular task is certainly
-                # long gone -- it must have cancelled.
-                pass
+            ret = sync_fn(*args)
+
+            if inspect.iscoroutine(ret):
+                # Manually close coroutine to avoid RuntimeWarnings
+                ret.close()
+                raise TypeError(
+                    "Trio expected a sync function, but {!r} appears to be "
+                    "asynchronous".format(getattr(sync_fn, "__qualname__", sync_fn))
+                )
+
+            return ret
         finally:
             del TOKEN_LOCAL.token
 
+    def deliver_worker_fn_result(result):
+        try:
+            current_trio_token.run_sync_soon(report_back_in_trio_thread_fn, result)
+        except trio.RunFinishedError:
+            # The entire run finished, so the task we're trying to contact is
+            # certainly long gone -- it must have been cancelled and abandoned
+            # us.
+            pass
+
     await limiter.acquire_on_behalf_of(placeholder)
     try:
-        # daemon=True because it might get left behind if we cancel, and in
-        # this case shouldn't block process exit.
-        current_trio_token = trio.lowlevel.current_trio_token()
-        thread = threading.Thread(
-            target=worker_thread_fn,
-            args=(current_trio_token,),
-            name=name,
-            daemon=True
-        )
-        thread.start()
+        start_thread_soon(worker_fn, deliver_worker_fn_result)
     except:
         limiter.release_on_behalf_of(placeholder)
         raise
@@ -329,18 +223,13 @@ def _run_fn_as_system_task(cb, fn, *args, trio_token=None):
                 "this thread wasn't created by Trio, pass kwarg trio_token=..."
             )
 
-    # TODO: This is only necessary for compatibility with BlockingTrioPortal.
-    # once that is deprecated, this check should no longer be necessary because
-    # thread local storage (or the absence of) is sufficient to check if trio
-    # is running in a thread or not.
+    # Avoid deadlock by making sure we're not called from Trio thread
     try:
         trio.lowlevel.current_task()
     except RuntimeError:
         pass
     else:
-        raise RuntimeError(
-            "this is a blocking function; call it from a thread"
-        )
+        raise RuntimeError("this is a blocking function; call it from a thread")
 
     q = stdlib_queue.Queue()
     trio_token.run_sync_soon(cb, q, fn, args)
@@ -380,6 +269,7 @@ def from_thread_run(afn, *args, trio_token=None):
           "foreign" thread, spawned using some other framework, and still want
           to enter Trio.
     """
+
     def callback(q, afn, args):
         @disable_ki_protection
         async def unprotected_afn():
@@ -424,6 +314,7 @@ def from_thread_run_sync(fn, *args, trio_token=None):
           "foreign" thread, spawned using some other framework, and still want
           to enter Trio.
     """
+
     def callback(q, fn, args):
         @disable_ki_protection
         def unprotected_fn():
