@@ -8,7 +8,7 @@ from functools import partial
 
 from OpenSSL import SSL
 import trustme
-from async_generator import async_generator, yield_, asynccontextmanager
+from async_generator import asynccontextmanager
 
 import trio
 from .. import _core
@@ -89,24 +89,25 @@ def ssl_echo_serve_sync(sock, *, expect_fail=False):
         wrapped = SERVER_CTX.wrap_socket(
             sock, server_side=True, suppress_ragged_eofs=False
         )
-        wrapped.do_handshake()
-        while True:
-            data = wrapped.recv(4096)
-            if not data:
-                # other side has initiated a graceful shutdown; we try to
-                # respond in kind but it's legal for them to have already gone
-                # away.
-                exceptions = (BrokenPipeError, ssl.SSLZeroReturnError)
-                # Under unclear conditions, CPython sometimes raises
-                # SSLWantWriteError here. This is a bug (bpo-32219), but it's
-                # not our bug, so ignore it.
-                exceptions += (ssl.SSLWantWriteError,)
-                try:
-                    wrapped.unwrap()
-                except exceptions:
-                    pass
-                return
-            wrapped.sendall(data)
+        with wrapped:
+            wrapped.do_handshake()
+            while True:
+                data = wrapped.recv(4096)
+                if not data:
+                    # other side has initiated a graceful shutdown; we try to
+                    # respond in kind but it's legal for them to have already
+                    # gone away.
+                    exceptions = (BrokenPipeError, ssl.SSLZeroReturnError)
+                    # Under unclear conditions, CPython sometimes raises
+                    # SSLWantWriteError here. This is a bug (bpo-32219), but
+                    # it's not our bug, so ignore it.
+                    exceptions += (ssl.SSLWantWriteError,)
+                    try:
+                        wrapped.unwrap()
+                    except exceptions:
+                        pass
+                    return
+                wrapped.sendall(data)
     # This is an obscure workaround for an openssl bug. In server mode, in
     # some versions, openssl sends some extra data at the end of do_handshake
     # that it shouldn't send. Normally this is harmless, but, if the other
@@ -132,13 +133,14 @@ def ssl_echo_serve_sync(sock, *, expect_fail=False):
     else:
         if expect_fail:  # pragma: no cover
             raise RuntimeError("failed to fail?")
+    finally:
+        sock.close()
 
 
 # Fixture that gives a raw socket connected to a trio-test-1 echo server
 # (running in a thread). Useful for testing making connections with different
 # SSLContexts.
 @asynccontextmanager
-@async_generator
 async def ssl_echo_server_raw(**kwargs):
     a, b = stdlib_socket.socketpair()
     async with trio.open_nursery() as nursery:
@@ -147,24 +149,18 @@ async def ssl_echo_server_raw(**kwargs):
         # nursery context manager to exit too.
         with a, b:
             nursery.start_soon(
-                trio.to_thread.run_sync,
-                partial(ssl_echo_serve_sync, b, **kwargs)
+                trio.to_thread.run_sync, partial(ssl_echo_serve_sync, b, **kwargs),
             )
 
-            await yield_(SocketStream(tsocket.from_stdlib_socket(a)))
+            yield SocketStream(tsocket.from_stdlib_socket(a))
 
 
 # Fixture that gives a properly set up SSLStream connected to a trio-test-1
 # echo server (running in a thread)
 @asynccontextmanager
-@async_generator
 async def ssl_echo_server(client_ctx, **kwargs):
     async with ssl_echo_server_raw(**kwargs) as sock:
-        await yield_(
-            SSLStream(
-                sock, client_ctx, server_hostname="trio-test-1.example.org"
-            )
-        )
+        yield SSLStream(sock, client_ctx, server_hostname="trio-test-1.example.org")
 
 
 # The weird in-memory server ... thing.
@@ -175,13 +171,12 @@ class PyOpenSSLEchoStream:
         ctx = SSL.Context(SSL.SSLv23_METHOD)
         # TLS 1.3 removes renegotiation support. Which is great for them, but
         # we still have to support versions before that, and that means we
-        # need to test renegotation support, which means we need to force this
+        # need to test renegotiation support, which means we need to force this
         # to use a lower version where this test server can trigger
         # renegotiations. Of course TLS 1.3 support isn't released yet, but
         # I'm told that this will work once it is. (And once it is we can
-        # remove the pragma: no cover too.) Alternatively, once we drop
-        # support for CPython 3.5 on macOS, then we could switch to using
-        # TLSv1_2_METHOD.
+        # remove the pragma: no cover too.) Alternatively, we could switch to
+        # using TLSv1_2_METHOD.
         #
         # Discussion: https://github.com/pyca/pyopenssl/issues/624
 
@@ -195,6 +190,7 @@ class PyOpenSSLEchoStream:
         # Fortunately pyopenssl uses cryptography under the hood, so we can be
         # confident that they're using the same version of openssl
         from cryptography.hazmat.bindings.openssl.binding import Binding
+
         b = Binding()
         if hasattr(b.lib, "SSL_OP_NO_TLSv1_3"):
             ctx.set_options(b.lib.SSL_OP_NO_TLSv1_3)
@@ -363,9 +359,7 @@ async def test_PyOpenSSLEchoStream_gives_resource_busy_errors():
 @contextmanager
 def virtual_ssl_echo_server(client_ctx, **kwargs):
     fakesock = PyOpenSSLEchoStream(**kwargs)
-    yield SSLStream(
-        fakesock, client_ctx, server_hostname="trio-test-1.example.org"
-    )
+    yield SSLStream(fakesock, client_ctx, server_hostname="trio-test-1.example.org")
 
 
 def ssl_wrap_pair(
@@ -374,13 +368,13 @@ def ssl_wrap_pair(
     server_transport,
     *,
     client_kwargs={},
-    server_kwargs={}
+    server_kwargs={},
 ):
     client_ssl = SSLStream(
         client_transport,
         client_ctx,
         server_hostname="trio-test-1.example.org",
-        **client_kwargs
+        **client_kwargs,
     )
     server_ssl = SSLStream(
         server_transport, SERVER_CTX, server_side=True, **server_kwargs
@@ -390,16 +384,12 @@ def ssl_wrap_pair(
 
 def ssl_memory_stream_pair(client_ctx, **kwargs):
     client_transport, server_transport = memory_stream_pair()
-    return ssl_wrap_pair(
-        client_ctx, client_transport, server_transport, **kwargs
-    )
+    return ssl_wrap_pair(client_ctx, client_transport, server_transport, **kwargs)
 
 
 def ssl_lockstep_stream_pair(client_ctx, **kwargs):
     client_transport, server_transport = lockstep_stream_pair()
-    return ssl_wrap_pair(
-        client_ctx, client_transport, server_transport, **kwargs
-    )
+    return ssl_wrap_pair(client_ctx, client_transport, server_transport, **kwargs)
 
 
 # Simple smoke test for handshake/send/receive/shutdown talking to a
@@ -416,9 +406,7 @@ async def test_ssl_client_basics(client_ctx):
     # Didn't configure the CA file, should fail
     async with ssl_echo_server_raw(expect_fail=True) as sock:
         bad_client_ctx = ssl.create_default_context()
-        s = SSLStream(
-            sock, bad_client_ctx, server_hostname="trio-test-1.example.org"
-        )
+        s = SSLStream(sock, bad_client_ctx, server_hostname="trio-test-1.example.org")
         assert not s.server_side
         with pytest.raises(BrokenResourceError) as excinfo:
             await s.send_all(b"x")
@@ -426,9 +414,7 @@ async def test_ssl_client_basics(client_ctx):
 
     # Trusted CA, but wrong host name
     async with ssl_echo_server_raw(expect_fail=True) as sock:
-        s = SSLStream(
-            sock, client_ctx, server_hostname="trio-test-2.example.org"
-        )
+        s = SSLStream(sock, client_ctx, server_hostname="trio-test-2.example.org")
         assert not s.server_side
         with pytest.raises(BrokenResourceError) as excinfo:
             await s.send_all(b"x")
@@ -445,13 +431,13 @@ async def test_ssl_server_basics(client_ctx):
         assert server_transport.server_side
 
         def client():
-            client_sock = client_ctx.wrap_socket(
+            with client_ctx.wrap_socket(
                 a, server_hostname="trio-test-1.example.org"
-            )
-            client_sock.sendall(b"x")
-            assert client_sock.recv(1) == b"y"
-            client_sock.sendall(b"z")
-            client_sock.unwrap()
+            ) as client_sock:
+                client_sock.sendall(b"x")
+                assert client_sock.recv(1) == b"y"
+                client_sock.sendall(b"z")
+                client_sock.unwrap()
 
         t = threading.Thread(target=client)
         t.start()
@@ -469,9 +455,7 @@ async def test_attributes(client_ctx):
     async with ssl_echo_server_raw(expect_fail=True) as sock:
         good_ctx = client_ctx
         bad_ctx = ssl.create_default_context()
-        s = SSLStream(
-            sock, good_ctx, server_hostname="trio-test-1.example.org"
-        )
+        s = SSLStream(sock, good_ctx, server_hostname="trio-test-1.example.org")
 
         assert s.transport_stream is sock
 
@@ -598,6 +582,7 @@ async def test_renegotiation_randomized(mock_clock, client_ctx):
     mock_clock.autojump_threshold = 0
 
     import random
+
     r = random.Random(0)
 
     async def sleeper(_):
@@ -634,8 +619,8 @@ async def test_renegotiation_randomized(mock_clock, client_ctx):
         await clear()
 
         for i in range(100):
-            b1 = bytes([i % 0xff])
-            b2 = bytes([(2 * i) % 0xff])
+            b1 = bytes([i % 0xFF])
+            b2 = bytes([(2 * i) % 0xFF])
             s.transport_stream.renegotiate()
             async with _core.open_nursery() as nursery:
                 nursery.start_soon(send, b1)
@@ -646,8 +631,8 @@ async def test_renegotiation_randomized(mock_clock, client_ctx):
             await clear()
 
         for i in range(100):
-            b1 = bytes([i % 0xff])
-            b2 = bytes([(2 * i) % 0xff])
+            b1 = bytes([i % 0xFF])
+            b2 = bytes([(2 * i) % 0xFF])
             await send(b1)
             s.transport_stream.renegotiate()
             await expect(b1)
@@ -673,9 +658,7 @@ async def test_renegotiation_randomized(mock_clock, client_ctx):
         await trio.sleep(1000)
         await s.wait_send_all_might_not_block()
 
-    with virtual_ssl_echo_server(
-        client_ctx, sleeper=sleeper_with_slow_send_all
-    ) as s:
+    with virtual_ssl_echo_server(client_ctx, sleeper=sleeper_with_slow_send_all) as s:
         await send(b"x")
         s.transport_stream.renegotiate()
         async with _core.open_nursery() as nursery:
@@ -1028,7 +1011,7 @@ async def test_ssl_bad_shutdown_but_its_ok(client_ctx):
     client, server = ssl_memory_stream_pair(
         client_ctx,
         server_kwargs={"https_compatible": True},
-        client_kwargs={"https_compatible": True}
+        client_kwargs={"https_compatible": True},
     )
 
     async with _core.open_nursery() as nursery:
@@ -1052,9 +1035,7 @@ async def test_ssl_handshake_failure_during_aclose():
     async with ssl_echo_server_raw(expect_fail=True) as sock:
         # Don't configure trust correctly
         client_ctx = ssl.create_default_context()
-        s = SSLStream(
-            sock, client_ctx, server_hostname="trio-test-1.example.org"
-        )
+        s = SSLStream(sock, client_ctx, server_hostname="trio-test-1.example.org")
         # It's a little unclear here whether aclose should swallow the error
         # or let it escape. We *do* swallow the error if it arrives when we're
         # sending close_notify, because both sides closing the connection
@@ -1094,7 +1075,7 @@ async def test_ssl_https_compatibility_disagreement(client_ctx):
     client, server = ssl_memory_stream_pair(
         client_ctx,
         server_kwargs={"https_compatible": False},
-        client_kwargs={"https_compatible": True}
+        client_kwargs={"https_compatible": True},
     )
 
     async with _core.open_nursery() as nursery:
@@ -1117,7 +1098,7 @@ async def test_https_mode_eof_before_handshake(client_ctx):
     client, server = ssl_memory_stream_pair(
         client_ctx,
         server_kwargs={"https_compatible": True},
-        client_kwargs={"https_compatible": True}
+        client_kwargs={"https_compatible": True},
     )
 
     async def server_expect_clean_eof():
@@ -1190,8 +1171,7 @@ async def test_selected_alpn_protocol_when_not_set(client_ctx):
     assert client.selected_alpn_protocol() is None
     assert server.selected_alpn_protocol() is None
 
-    assert client.selected_alpn_protocol() == \
-        server.selected_alpn_protocol()
+    assert client.selected_alpn_protocol() == server.selected_alpn_protocol()
 
 
 async def test_selected_npn_protocol_before_handshake(client_ctx):
@@ -1216,8 +1196,7 @@ async def test_selected_npn_protocol_when_not_set(client_ctx):
     assert client.selected_npn_protocol() is None
     assert server.selected_npn_protocol() is None
 
-    assert client.selected_npn_protocol() == \
-        server.selected_npn_protocol()
+    assert client.selected_npn_protocol() == server.selected_npn_protocol()
 
 
 async def test_get_channel_binding_before_handshake(client_ctx):
@@ -1240,8 +1219,7 @@ async def test_get_channel_binding_after_handshake(client_ctx):
     assert client.get_channel_binding() is not None
     assert server.get_channel_binding() is not None
 
-    assert client.get_channel_binding() == \
-        server.get_channel_binding()
+    assert client.get_channel_binding() == server.get_channel_binding()
 
 
 async def test_getpeercert(client_ctx):
@@ -1254,10 +1232,7 @@ async def test_getpeercert(client_ctx):
 
     assert server.getpeercert() is None
     print(client.getpeercert())
-    assert (
-        ("DNS", "trio-test-1.example.org")
-        in client.getpeercert()["subjectAltName"]
-    )
+    assert ("DNS", "trio-test-1.example.org") in client.getpeercert()["subjectAltName"]
 
 
 async def test_SSLListener(client_ctx):
@@ -1270,9 +1245,7 @@ async def test_SSLListener(client_ctx):
 
         transport_client = await open_tcp_stream(*listen_sock.getsockname())
         ssl_client = SSLStream(
-            transport_client,
-            client_ctx,
-            server_hostname="trio-test-1.example.org"
+            transport_client, client_ctx, server_hostname="trio-test-1.example.org",
         )
         return listen_sock, ssl_listener, ssl_client
 
