@@ -8,12 +8,13 @@ from .. import _core
 from .. import Event, CapacityLimiter, sleep
 from ..testing import wait_all_tasks_blocked
 from .._threads import (
-    to_thread_run_sync, current_default_thread_limiter, from_thread_run,
-    from_thread_run_sync, BlockingTrioPortal
+    to_thread_run_sync,
+    current_default_thread_limiter,
+    from_thread_run,
+    from_thread_run_sync,
 )
 
 from .._core.tests.test_ki import ki_self
-from .._core.tests.tutil import slow
 
 
 async def test_do_in_trio_thread():
@@ -36,9 +37,7 @@ async def test_do_in_trio_thread():
         while child_thread.is_alive():
             print("yawn")
             await sleep(0.01)
-        assert record == [
-            ("start", child_thread), ("f", trio_thread), expected
-        ]
+        assert record == [("start", child_thread), ("f", trio_thread), expected]
 
     token = _core.current_trio_token()
 
@@ -54,9 +53,7 @@ async def test_do_in_trio_thread():
         record.append(("f", threading.current_thread()))
         raise ValueError
 
-    await check_case(
-        from_thread_run_sync, f, ("error", ValueError), trio_token=token
-    )
+    await check_case(from_thread_run_sync, f, ("error", ValueError), trio_token=token)
 
     async def f(record):
         assert not _core.currently_ki_protected()
@@ -102,6 +99,7 @@ def test_run_in_trio_thread_ki():
                 ki_self()
             finally:
                 import sys
+
                 print("finally", sys.exc_info())
 
         async def trio_thread_afn():
@@ -240,7 +238,9 @@ async def test_run_in_worker_thread_cancellation():
 # Make sure that if trio.run exits, and then the thread finishes, then that's
 # handled gracefully. (Requires that the thread result machinery be prepared
 # for call_soon to raise RunFinishedError.)
-def test_run_in_worker_thread_abandoned(capfd):
+def test_run_in_worker_thread_abandoned(capfd, monkeypatch):
+    monkeypatch.setattr(_core._thread_cache, "IDLE_TIMEOUT", 0.01)
+
     q1 = stdlib_queue.Queue()
     q2 = stdlib_queue.Queue()
 
@@ -269,7 +269,8 @@ def test_run_in_worker_thread_abandoned(capfd):
 
     # Make sure we don't have a "Exception in thread ..." dump to the console:
     out, err = capfd.readouterr()
-    assert not out and not err
+    assert "Exception in thread" not in out
+    assert "Exception in thread" not in err
 
 
 @pytest.mark.parametrize("MAX", [3, 5, 10])
@@ -333,15 +334,9 @@ async def test_run_in_worker_thread_limiter(MAX, cancel, use_default_limiter):
         async def run_thread(event):
             with _core.CancelScope() as cancel_scope:
                 await to_thread_run_sync(
-                    thread_fn,
-                    cancel_scope,
-                    limiter=limiter_arg,
-                    cancellable=cancel
+                    thread_fn, cancel_scope, limiter=limiter_arg, cancellable=cancel,
                 )
-            print(
-                "run_thread finished, cancelled:",
-                cancel_scope.cancelled_caught
-            )
+            print("run_thread finished, cancelled:", cancel_scope.cancelled_caught)
             event.set()
 
         async with _core.open_nursery() as nursery:
@@ -433,10 +428,10 @@ async def test_run_in_worker_thread_limiter_error():
 
 async def test_run_in_worker_thread_fail_to_spawn(monkeypatch):
     # Test the unlikely but possible case where trying to spawn a thread fails
-    def bad_start(self):
+    def bad_start(self, *args):
         raise RuntimeError("the engines canna take it captain")
 
-    monkeypatch.setattr(threading.Thread, "start", bad_start)
+    monkeypatch.setattr(_core._thread_cache.ThreadCache, "start_thread_soon", bad_start)
 
     limiter = current_default_thread_limiter()
     assert limiter.borrowed_tokens == 0
@@ -461,6 +456,15 @@ async def test_trio_to_thread_run_sync_token():
     assert callee_token == caller_token
 
 
+async def test_trio_to_thread_run_sync_expected_error():
+    # Test correct error when passed async function
+    async def async_fn():  # pragma: no cover
+        pass
+
+    with pytest.raises(TypeError, match="expected a sync function"):
+        await to_thread_run_sync(async_fn)
+
+
 async def test_trio_from_thread_run_sync():
     # Test that to_thread_run_sync correctly "hands off" the trio token to
     # trio.from_thread.run_sync()
@@ -471,6 +475,16 @@ async def test_trio_from_thread_run_sync():
     trio_time = await to_thread_run_sync(thread_fn)
     assert isinstance(trio_time, float)
 
+    # Test correct error when passed async function
+    async def async_fn():  # pragma: no cover
+        pass
+
+    def thread_fn():
+        from_thread_run_sync(async_fn)
+
+    with pytest.raises(TypeError, match="expected a sync function"):
+        await to_thread_run_sync(thread_fn)
+
 
 async def test_trio_from_thread_run():
     # Test that to_thread_run_sync correctly "hands off" the trio token to
@@ -488,6 +502,13 @@ async def test_trio_from_thread_run():
     await to_thread_run_sync(thread_fn)
     assert record == ["in thread", "back in trio"]
 
+    # Test correct error when passed sync function
+    def sync_fn():  # pragma: no cover
+        pass
+
+    with pytest.raises(TypeError, match="appears to be synchronous"):
+        await to_thread_run_sync(from_thread_run, sync_fn)
+
 
 async def test_trio_from_thread_token():
     # Test that to_thread_run_sync and spawned trio.from_thread.run_sync()
@@ -505,9 +526,7 @@ async def test_trio_from_thread_token_kwarg():
     # Test that to_thread_run_sync and spawned trio.from_thread.run_sync() can
     # use an explicitly defined token
     def thread_fn(token):
-        callee_token = from_thread_run_sync(
-            _core.current_trio_token, trio_token=token
-        )
+        callee_token = from_thread_run_sync(_core.current_trio_token, trio_token=token)
         return callee_token
 
     caller_token = _core.current_trio_token()
@@ -525,44 +544,13 @@ async def test_from_thread_no_token():
 
 def test_run_fn_as_system_task_catched_badly_typed_token():
     with pytest.raises(RuntimeError):
-        from_thread_run_sync(
-            _core.current_time, trio_token="Not TrioTokentype"
-        )
+        from_thread_run_sync(_core.current_time, trio_token="Not TrioTokentype")
 
 
-async def test_do_in_trio_thread_from_trio_thread_legacy():
-    # This check specifically confirms that a RuntimeError will be raised if
-    # the old BlockingTrIoPortal API calls into a trio loop while already
-    # running inside of one.
-    portal = BlockingTrioPortal()
+async def test_from_thread_inside_trio_thread():
+    def not_called():  # pragma: no cover
+        assert False
 
+    trio_token = _core.current_trio_token()
     with pytest.raises(RuntimeError):
-        portal.run_sync(lambda: None)  # pragma: no branch
-
-    async def foo():  # pragma: no cover
-        pass
-
-    with pytest.raises(RuntimeError):
-        portal.run(foo)
-
-
-async def test_BlockingTrioPortal_with_explicit_TrioToken():
-    # This tests the deprecated BlockingTrioPortal with a token passed in to
-    # confirm that both methods of making a portal are supported by
-    # trio.from_thread
-    token = _core.current_trio_token()
-
-    def worker_thread(token):
-        with pytest.raises(RuntimeError):
-            BlockingTrioPortal()
-        portal = BlockingTrioPortal(token)
-        return portal.run_sync(threading.current_thread)
-
-    t = await to_thread_run_sync(worker_thread, token)
-    assert t == threading.current_thread()
-
-
-def test_BlockingTrioPortal_deprecated_export(recwarn):
-    import trio
-    btp = trio.BlockingTrioPortal
-    assert btp is BlockingTrioPortal
+        from_thread_run_sync(not_called, trio_token=trio_token)
